@@ -8,12 +8,14 @@ Directives, roles and nodes for text formatting.
 .. extensions:: sphinx_toolbox.formatting
 
 
+.. latex:vspace:: -10px
+
 Usage
 -------
 
 .. rst:role:: iabbr
 
-	An abbreviation. If the role content contains a parenthesized  explanation,
+	An abbreviation. If the role content contains a parenthesized explanation,
 	it will be treated specially: it will be shown in a tool-tip in HTML,
 	and output only once in LaTeX.
 
@@ -21,13 +23,30 @@ Usage
 
 	.. versionadded:: 0.2.0
 
-	**Example**
+	:bold-title:`Example`
 
 	.. rest-example::
 
 		:iabbr:`LIFO (last-in, first-out)`
 
 
+.. rst:role:: bold-title
+
+	Role for displaying a pseudo title in bold.
+
+	This is useful for breaking up Python docstrings.
+
+	.. versionadded:: 2.12.0
+
+	:bold-title:`Example`
+
+	.. rest-example::
+
+		:bold-title:`Examples:`
+
+		:bold-title:`Other Extensions`
+
+
 API Reference
 ---------------
 """
@@ -64,6 +83,7 @@ from docutils.nodes import Node, system_message
 from docutils.parsers.rst import roles
 from sphinx.application import Sphinx
 from sphinx.roles import Abbreviation
+from sphinx.util.docutils import SphinxRole
 from sphinx.writers.html import HTMLTranslator
 from sphinx.writers.latex import LaTeXTranslator
 
@@ -97,16 +117,35 @@ class ItalicAbbreviation(Abbreviation):
 		Process the content of the italic abbreviation role.
 		"""
 
-		options = self.options.copy()  # type: ignore
-		matched = self.abbr_re.search(self.text)  # type: ignore
+		options = self.options.copy()
+		matched = self.abbr_re.search(self.text)
 
 		if matched:
-			text = self.text[:matched.start()].strip()  # type: ignore
+			text = self.text[:matched.start()].strip()
 			options["explanation"] = matched.group(1)
 		else:
 			text = self.text
 
-		return [ItalicAbbreviationNode(self.rawtext, text, **options)], []  # type: ignore
+		return [ItalicAbbreviationNode(self.rawtext, text, **options)], []
+
+
+class BoldTitle(SphinxRole):
+	"""
+	Role for displaying a pseudo title in bold.
+
+	This is useful for breaking up Python docstrings.
+	"""
+
+	def run(self) -> Tuple[List[nodes.Node], List[nodes.system_message]]:
+
+		assert self.text is not None
+
+		node_list: List[nodes.Node] = [
+				nodes.raw('', r"\vspace{10px}", format="latex"),
+				nodes.strong(f"**{self.text}**", self.text),
+				]
+
+		return node_list, []
 
 
 def visit_iabbr_node(translator: HTMLTranslator, node: ItalicAbbreviationNode):
@@ -177,6 +216,8 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 
 	roles.register_local_role("iabbr", ItalicAbbreviation())
+	app.add_role("bold-title", BoldTitle())
+
 	app.add_node(
 			ItalicAbbreviationNode,
 			html=(visit_iabbr_node, depart_iabbr_node),
