@@ -647,7 +647,7 @@ def copy_asset_files(app: Sphinx, exception: Optional[Exception] = None):
 	if exception:  # pragma: no cover
 		return
 
-	if app.builder is None or app.builder.format.lower() != "html":
+	if app.builder is None or app.builder.format.lower() != "html":  # pragma: no cover
 		return
 
 	static_dir = PathPlus(app.outdir) / "_static"
