@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 #
 #  latex_layout.py
-"""
+r"""
 Makes minor adjustments to the LaTeX layout.
 
 * Increases the whitespace above function signatures by 5px,
@@ -13,12 +13,23 @@ Makes minor adjustments to the LaTeX layout.
 
   .. versionadded:: 2.12.0
 
+* With Sphinx 3.5, doesn't add ``\sphinxAtStartPar`` before every paragraph.
+  The change in :github:issue:`8781 <sphinx-doc/sphinx>` was to solve an issue with *tables*,
+  but it isn't clear why it then gets added for *every* paragraph so this extension removes it.
+
+  .. versionadded:: 2.13.0
+
+* Configures hyperref to apply correct page numbering to the frontmatter.
+
+  .. versionadded:: 2.14.0
+
+
 .. versionadded:: 2.10.0
 .. extensions:: sphinx_toolbox.tweaks.latex_layout
 
 -----
 
-"""  # noqa: D400
+"""
 #
 #  Copyright © 2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
@@ -45,6 +56,7 @@ Makes minor adjustments to the LaTeX layout.
 from docutils import nodes
 from sphinx import addnodes
 from sphinx.application import Sphinx
+from sphinx.builders.latex.nodes import footnotetext
 from sphinx.config import Config
 from sphinx.writers.latex import LaTeXTranslator
 
@@ -98,6 +110,39 @@ def configure(app: Sphinx, config: Config):
 			r"\makeatother",
 			])
 
+	config.latex_elements["hyperref"] = '\n'.join([
+			r"% Include hyperref last.",
+			r"\usepackage[pdfpagelabels,hyperindex,hyperfigures]{hyperref}",
+			r"% Fix anchor placement for figures with captions.",
+			r"\usepackage{hypcap}% it must be loaded after hyperref.",
+			])
+
+	config.latex_elements["maketitle"] = '\n'.join([
+			r"\begingroup",
+			r"\let\oldthepage\thepage",
+			r"\renewcommand{\thepage}{T\oldthepage}",
+			config.latex_elements.get("maketitle", r"\sphinxmaketitle"),
+			r"\endgroup"
+			])
+
+
+def visit_paragraph(translator: LaTeXTranslator, node: nodes.paragraph) -> None:
+	index = node.parent.index(node)
+	if (
+			index > 0 and isinstance(node.parent, nodes.compound)
+			and not isinstance(node.parent[index - 1], nodes.paragraph)
+			and not isinstance(node.parent[index - 1], nodes.compound)
+			):
+		# insert blank line, if the paragraph follows a non-paragraph node in a compound
+		translator.body.append("\\noindent\n")
+	elif index == 1 and isinstance(node.parent, (nodes.footnote, footnotetext)):
+		# don't insert blank line, if the paragraph is second child of a footnote
+		# (first one is label node)
+		pass
+	else:
+		# Sphinx 3.5 adds \sphinxAtStartPar here, but I don't see what it gains.
+		translator.body.append('\n')
+
 
 @metadata_add_version
 def setup(app: Sphinx) -> SphinxExtMetadata:
@@ -107,9 +152,10 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	:param app: The Sphinx application.
 	"""
 
-	app.connect("config-inited", configure)
+	app.connect("config-inited", configure, priority=500)
 
 	app.add_node(addnodes.desc, latex=(visit_desc, LaTeXTranslator.depart_desc), override=True)
 	app.add_node(nodes.field_list, latex=(visit_field_list, depart_field_list), override=True)
+	app.add_node(nodes.paragraph, latex=(visit_paragraph, LaTeXTranslator.depart_paragraph), override=True)
 
 	return {"parallel_read_safe": True}
